@@ -5,6 +5,7 @@ from __future__ import annotations
 import datetime
 import regex as re
 from lxml import etree
+
 from arelle.XbrlConst import ixbrlAll, qnLinkFootnote, xhtml, xml, xsd, xhtml
 from arelle.ModelObject import ModelObject
 from arelle.ModelValue import qname, QName, tzinfoStr
@@ -181,6 +182,12 @@ def textNotStripped(element: ModelObject | PrototypeObject | None) -> str:
         return ""
     return element.textValue  # allows embedded comment nodes, returns '' if None
 
+def selfClosable(elt: ModelObject) -> bool:
+    return elt.qname.localName in (
+        'area', 'base', 'basefont', 'br', 'col', 'frame', 'hr', 'img',
+        'input', 'isindex', 'link', 'meta', 'param'
+    )
+
 # ixEscape can be None, "html" (xhtml namespace becomes default), "xhtml", or "xml"
 def innerText(
     element: ModelObject,
@@ -260,9 +267,10 @@ def escapedNode(
     if not start and not empty:
         s.append('/')
     if ixEscape == "html" and elt.qname.namespaceURI == xhtml:
-        s.append(elt.qname.localName)  # force xhtml prefix to be default
+        tagName = elt.qname.localName # force xhtml prefix to be default
     else:
-        s.append(str(elt.qname))
+        tagName = str(elt.qname)
+    s.append(tagName)
     if start or empty:
         assert resolveHtmlUri is not None
         if elt.localName == "object" and elt.get("codebase"): # resolve codebase before other element names
@@ -276,7 +284,10 @@ def escapedNode(
             s.append(' {0}="{1}"'.format(qname(elt, cast(str, n)),
                 cast(str, v).replace("&","&amp;").replace('"', '&quot;')))
     if not start and empty:
-        s.append('/')
+        if selfClosable(elt):
+            s.append('/')
+        else:
+            s.append('></' + tagName)
     s.append('>')
     return ''.join(s)
 
@@ -423,13 +434,13 @@ def descendantAttr(
     return descendantElt.get(attrClarkName) if (descendantElt is not None) else None
 
 def children(
-    element: ModelObject,
+    element: ModelObject | etree._ElementTree | PrototypeElementTree,
     childNamespaceURIs: str | tuple[str, ...] | None,
     childLocalNames: str | tuple[str, ...],
     ixTarget: bool = False
     # 2022-09-15 ModelUnit/Context are model objects,
     # the check in line ~444 below if for ModelObject base class
-) -> list[ModelObject]:
+) -> Sequence[ModelObject]:
     children = []
     if not isinstance(childLocalNames,tuple): childLocalNames = (childLocalNames ,)
     wildLocalName = childLocalNames == ('*',)
@@ -520,7 +531,7 @@ def descendants(
     attrValue: str | None = None,
     breakOnFirst: bool = False,
     ixTarget: bool = False
-) -> list[ModelObject | PrototypeObject]:
+) -> Sequence[ModelObject | PrototypeObject]:
     descendants = []
     if not isinstance(descendantLocalNames,tuple): descendantLocalNames = (descendantLocalNames ,)
     wildLocalName = descendantLocalNames == ('*',)
