@@ -40,6 +40,9 @@ Input file parameters may be in JSON (without newlines for pretty printing as be
    "filerNewRegistrantFlag": true/false, # JSON Boolean, string Yes/No, yes/no, Y/N, y/n or absent
    # Test/debug fields
    datetimeForTesting: xml-syntax datetime to override clock time for test/debug purposes
+   dqcRuleFilter: null or absent for all DQC rules, else regular expression to filter which rules run
+       (e.g. "DQC.US.00(04|15)" ), but not including the id suffix (which is not filterable)
+       If parameter is absent and config.xml for disclosureSystem options specifies a dqc-rule-filter, it will be in effect
    },
  {"file": "file 2"...
 ]
@@ -132,7 +135,7 @@ def validateXbrlStart(val, parameters=None, *args, **kwargs):
                       "emergingGrowthCompanyFlag", "exTransitionPeriodFlag", "invCompanyType",
                       "rptIncludeAllSeriesFlag", "rptSeriesClassInfo.seriesIds", "newClass2.seriesIds",
                       "eligibleFundFlag", "pursuantGeneralInstructionFlag", "filerNewRegistrantFlag",
-                      "datetimeForTesting")
+                      "datetimeForTesting", "dqcRuleFilter")
     parameterEisFileTags = {
         "cik":["depositorId", "cik", "filerId"],
         "submissionType": "submissionType",
@@ -233,6 +236,9 @@ def validateXbrlStart(val, parameters=None, *args, **kwargs):
            for concept in val.modelXbrl.nameConcepts.get("UTR",())):
         val.validateUTR = True
 
+    if "dqcRuleFilter" not in val.params and val.disclosureSystem.options and "dqc-rule-filter=" in val.disclosureSystem.options:
+        val.params["dqcRuleFilter"] = val.disclosureSystem.options.partition("dqc-rule-filter=")[2]
+
     modelManager = val.modelXbrl.modelManager
     if hasattr(modelManager, "efmFiling"):
         efmFiling = modelManager.efmFiling
@@ -686,7 +692,7 @@ class Report:
 __pluginInfo__ = {
     # Do not use _( ) in pluginInfo itself (it is applied later, after loading
     'name': 'Validate EFM',
-    'version': '1.22.4', # SEC EDGAR release 22.4
+    'version': '1.23.1', # SEC EDGAR release 23.1
     'description': '''EFM Validation.''',
     'license': 'Apache-2',
     'import': ('transforms/SEC',), # SEC inline can use SEC transformations
